@@ -12,7 +12,7 @@ import os
 import sys
 import pkgutil
 
-
+_basic_dict = dict()
 # 依次扫描glowworm下所有除main的模块
 for importer, modname, ispkg in pkgutil.iter_modules(path=['glowworm']):
     if ispkg:
@@ -27,8 +27,8 @@ for importer, modname, ispkg in pkgutil.iter_modules(path=['glowworm']):
             if class_.__base__ != pysmart.Base:
                 continue
             smart_dict = class_.__dict__
-            _basic_dict = {smart_dict[f].__doc__: smart_dict[f] for f in smart_dict
-                           if isfunction(smart_dict[f])}
+            _basic_dict = {**{smart_dict[f].__doc__: smart_dict[f] for f in smart_dict
+                              if isfunction(smart_dict[f])}, **_basic_dict}
     except KeyError as key_err:
         print('warn: 模块{}中没有类或没有继承Base类'.format(modname))
         continue
